# Tutorial

EN | [RU](/docs/tutorial/ru/0_tutorial.md)

Welcome to official telegrinder tutorial from our team and contributors. This tutorial is recommended to be read in order.

During the reading, if you have any questions, you are free to enter [any of community forums](/docs/community_links.md) and ask your questions. Please notice, that github issues are reserved for feature requests and bugs.

## Contents

1. [Welcome to telegrinder. Setting up](1_setting_up.md)
2. [Rules](2_rules.md)
3. [Functional Bits](3_functional_bits.md)
4. [Telegram API](4_api.md)
5. [Nodes](5_nodes.md)
6. [Dispatch, code separation](6_dispatch.md)
7. [Keyboard, payload handling](7_keyboard.md)
8. [Working with text: formatting, localizing](8_text.md)
9. [States: waiters, long states](9_states.md)
10. [Media](10_media.md)
11. [Handling errors](11_handling_errors.md)
12. [Out-of-box scenarios](12_out-of-box_scenarios.md)
